@@ -74,28 +74,22 @@ class QueryParamsMixin:
     """
 
     required_query_keys = []
-    optional_query_keys = []
-
     required_multivalue = []
-    optional_multivalue = []
 
     def get_queryparams(self):
-
-        result = {}
         missing_keys = set()
 
         queryparams = self.event.get("queryStringParameters") or {}
         multivalue_queryparams = self.event.get("multiValueQueryStringParameters") or {}
 
+        result = {**queryparams, **multivalue_queryparams}
+
         for key in self.required_query_keys:
-            if key in queryparams:
-                result[key] = queryparams[key]
-            else:
+            if key not in queryparams:
                 missing_keys.add(key)
+
         for key in self.required_multivalue:
-            if key in multivalue_queryparams:
-                result[key] = multivalue_queryparams[key]
-            else:
+            if key not in multivalue_queryparams:
                 missing_keys.add(key)
 
         if missing_keys:
@@ -103,14 +97,6 @@ class QueryParamsMixin:
             self.error = (message, 400)
             raise BadRequest(message=message)
 
-        # Collect all optional keys and values.
-        for key in self.optional_query_keys:
-            if key in queryparams:
-                result[key] = queryparams[key]
-        for key in self.optional_multivalue:
-            if key in multivalue_queryparams:
-                result[key] = multivalue_queryparams[key]
-
         return result
 
 
